pub enum RecvTimeoutError {
Timeout,
Disconnected,
}Expand description
This enumeration is the list of possible errors that made recv_timeout
unable to return data when called. This can occur with both a channel and
a sync_channel.
Variants
Timeout
This channel is currently empty, but the Sender(s) have not yet disconnected, so data may yet become available.
Disconnected
The channelโs sending half has become disconnected, and there will never be any more data received on it.